@@ -15,8 +15,7 @@ class ProductService(object):
     batch_service = ClientBatchRequest
 
     def insert_products(self, add_mapped=True, add_stock=True, add_price=True,
-                        add_images=False, add_categories=True, is_sync=True,
-                        is_success_log=True):
+                        add_categories=True, is_sync=True, is_success_log=True):
         with OmnitronIntegration(
                 content_type=ContentType.product.value) as omnitron_integration:
             products = omnitron_integration.do_action(
@@ -34,10 +33,6 @@ class ProductService(object):
                 products = products and omnitron_integration.do_action(
                     key='get_product_prices', objects=products)
 
-            if add_images:
-                products = products and omnitron_integration.do_action(
-                    key='get_product_images', objects=products)
-
             if add_categories:
                 products = products and omnitron_integration.do_action(
                     key='get_product_categories', objects=products)
@@ -78,8 +73,7 @@ class ProductService(object):
                     objects=response_data)
 
     def update_products(self, add_mapped=True, add_stock=True, add_price=True,
-                        add_images=False, add_categories=True, is_sync=True,
-                        is_success_log=True):
+                        add_categories=True, is_sync=True, is_success_log=True):
         with OmnitronIntegration(
                 content_type=ContentType.product.value) as omnitron_integration:
             products = omnitron_integration.do_action(
@@ -97,10 +91,6 @@ class ProductService(object):
                 products = products and omnitron_integration.do_action(
                     key='get_product_prices', objects=products)
 
-            if add_images:
-                products = products and omnitron_integration.do_action(
-                    key='get_product_images', objects=products)
-
             if add_categories:
                 products = products and omnitron_integration.do_action(
                     key='get_product_categories', objects=products)
